GenerateRBACWrapper class
Annotation to trigger RBAC wrapper code generation.
Apply this annotation to an abstract class to auto-generate a
<ClassName>Guarded wrapper that enforces permission checks defined with
Access on each method.
Constructors
- GenerateRBACWrapper()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited