prerequisites property
Set<Capability>
get
prerequisites
Other capabilities that must be available before this one.
Implementation
Set<Capability> get prerequisites;
Other capabilities that must be available before this one.
Set<Capability> get prerequisites;