availableFrom method
Returns only the capabilities from all that are currently available.
Implementation
List<Capability> availableFrom(Iterable<Capability> all) {
return all.where(isAvailable).toList();
}
Returns only the capabilities from all that are currently available.
List<Capability> availableFrom(Iterable<Capability> all) {
return all.where(isAvailable).toList();
}