CapabilityResult class

Detailed result of evaluating a Capability against a permission set.

Constructors

CapabilityResult({required Capability capability, required bool isAvailable, required Set<PermissionKey> missingPermissions, required Set<Capability> unmetPrerequisites})
const

Properties

capability Capability
The capability that was evaluated.
final
hasAllPermissions bool
Whether all directly required permissions are granted (ignores prerequisites).
no setter
hashCode int
The hash code for this object.
no setterinherited
isAvailable bool
Whether the capability is fully available.
final
missingPermissions Set<PermissionKey>
Directly required permissions that are not granted.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unmetPrerequisites Set<Capability>
Direct prerequisites that are not (recursively) available.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited