Access class

Declares how a repository method should be guarded.

Constructors

Access.none()
Skip RBAC checks for this method.
const
Access.permission(Object permission)
Require the current user to hold permission.
const
Access.self({required String ownerParam})
Require the current user to match the method argument named ownerParam.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
ownerParam String?
final
permission Object?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited