CapabilityCycleError class
Thrown when Capability.prerequisites form a cycle (a configuration bug).
Constructors
-
CapabilityCycleError(List<
String> path)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
path
→ List<
String> -
The chain of capability ids that loops back on itself.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
The stack trace at the point where this error was first thrown.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited