widgets library
Flutter UI helpers for RBAC.
Import this entry point in Flutter apps to use permission-aware widgets:
import 'package:rbac_client/widgets.dart';
Classes
- CapabilityGate
- Shows child only when capability is available for the current user; otherwise renders fallback (an empty box by default).
- PermissionGate
- Shows child only when the current user holds permission; otherwise renders fallback (an empty box by default).
- PermissionScope
- Provides the current user's granted permissions to the widget subtree.